@@ -13,8 +13,7 @@ class ListTest : public QObject
 {
     Q_OBJECT
 
-private Q_SLOTS:
-    void initTestCase();
+  private Q_SLOTS:
     void testListJob();
 
 private:
@@ -23,12 +22,6 @@ private:
 
 QTEST_GUILESS_MAIN(ListTest)
 
-void ListTest::initTestCase()
-{
-    // Avoid a runtime dependency on KLauncher.
-    qputenv("KDE_FORK_SLAVES", "yes");
-}
-
 void ListTest::testListJob()
 {
     const auto gdriveRoot = QUrl(QStringLiteral("gdrive:/"));
