@@ -12,13 +12,17 @@
 #include <QDataStream>
 #include <QEventLoop>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 
 #include <KIO/Job> //for stat.h
 #include <KGAPI/AuthJob>
 
-QString KeychainAccountManager::s_apiKey = QStringLiteral("554041944266.apps.googleusercontent.com");
-QString KeychainAccountManager::s_apiSecret = QStringLiteral("mdT1DjzohxN3npUUzkENT0gO");
+QString KeychainAccountManager::s_apiKey = QStringLiteral("836279663462-qq9rt1k4smgqhvt461r6l54vo9qm09bg.apps.googleusercontent.com");
+QString KeychainAccountManager::s_apiSecret = QStringLiteral("5-k19mrwsAud5a1r-qijtTJQ");
 
 
 QSet<QString> KeychainAccountManager::accounts()
@@ -45,7 +49,7 @@ KGAPI2::AccountPtr KeychainAccountManager::account(const QString &accountName)
 
     const auto entry = readMap(accountName);
 
-    const QStringList scopes = entry.value(QStringLiteral("scopes")).split(QLatin1Char(','), QString::SkipEmptyParts);
+    const QStringList scopes = entry.value(QStringLiteral("scopes")).split(QLatin1Char(','), Qt::SkipEmptyParts);
     QList<QUrl> scopeUrls;
     for (const QString &scope : scopes) {
         scopeUrls << QUrl::fromUserInput(scope);
